package ehtest;

import net.sf.ehcache.*;
import net.sf.ehcache.search.*;

import org.openjdk.jmh.annotations.*;
import org.openjdk.jmh.infra.Blackhole;

@State(Scope.Benchmark)
public class CacheTest
{
  private int cacheSize = 500000;
  private CacheManager manager;
  private Cache cache;

  @Setup
  public void fillCache()
  {
    // Create cache
    manager = CacheManager.create(CacheTest.class.getClassLoader().getResource("testCache.xml"));
    cache = manager.getCache("testCache");

    // Populate cache
    for(int i = 0; i < cacheSize; i++)
    {
      Integer id = Integer.valueOf(i);
      DataObject value = new DataObject();
      value.put("id", String.valueOf(id));
      value.put("name", "Object #"+i);
      value.put("type", "SimpleObject");
      cache.put(new Element(id, value));
    }
  }

  @TearDown
  public void shutdownCacheManager()
  {
     manager.shutdown();
  }

  @Benchmark   
  public void testSearch(Blackhole bh)
  {
    Query query = cache.createQuery().addCriteria(     cache.getSearchAttribute("name").eq("Object #100000")
                                                  .and(cache.getSearchAttribute("type").eq("SimpleObject"))).includeKeys();
    Results results = query.execute();
    bh.consume(results);
  }
}